@@ -59,7 +59,7 @@ Konfigurator::Konfigurator(bool f) : KDialogBase(0,0,true,"Konfigurator"), first
   createLayout();
   setMainWidget(widget);
   if (exec()) {
-	  KMessageBox::information(this,i18n("Changes to the GUI will be updated\nnext time you run Krusader."),
+	  KMessageBox::information(this,i18n("Changes to the GUI will be updated next time you run Krusader."),
 	    QString::null,"konfigGUInotify");
   }
 }
@@ -78,30 +78,24 @@ void Konfigurator::createLayout() {
   // welcome
   new kgWelcome(widget->addPage(i18n("Welcome"),i18n("Welcome to Konfigurator"),
     QPixmap(krLoader->loadIcon("krusader",KIcon::Desktop,32))));
-
   // startup
   newContent(new kgStartupImpl(firstTime, widget->addPage(i18n("Startup"),
     i18n("Krusader's setting upon startup"),QPixmap(krLoader->loadIcon("gear",
       KIcon::Desktop,32)))));
-
   // look n' feel
   newContent(new kgLookFeelImpl(firstTime, widget->addPage(i18n("Look & Feel"),
     i18n("Look & Feel"),QPixmap(krLoader->loadIcon("appearance",KIcon::Desktop,32)))));
-
   // general
   newContent(new kgGeneralImpl(firstTime, widget->addPage(i18n("General"),
     i18n("Basic Operations"),QPixmap(krLoader->loadIcon("configure",KIcon::Desktop,32)))));
-
   // advanced
   newContent(new kgAdvancedImpl(firstTime, widget->addPage(i18n("Advanced"),
     i18n("Be sure you know what you're doing"),
     QPixmap(krLoader->loadIcon("file_important",KIcon::Desktop,32)))));
-
   // archives
   newContent(new kgArchivesImpl(firstTime, widget->addPage(i18n("Archives"),
     i18n("Costumize the way Krusader deals with archives"),QPixmap(krLoader->loadIcon(
     "tgz",KIcon::Desktop,32)))));
-
   widget->showPage(0);
 }
 
