@@ -34,6 +34,8 @@
 #include <qfileinfo.h>
 #include <qtextstream.h>
 #include <qfile.h>
+#include <qtimer.h>
+#include <qdir.h>
 // KDE includes
 #include <kmessagebox.h>
 #include <kprocess.h>
@@ -104,6 +106,9 @@ QString KMountMan::nextWord(QString &s) {
 }
 
 QString KMountMan::followLink(QString source) {
+  // ugly hack - disable link following because of devfs
+  return source;
+
   QFileInfo temp(source);
   // if the file doesn't exist and it contains //, it's probably a samba share
   // <patch> thanks to Cristi Dumitrescu
@@ -133,7 +138,7 @@ bool KMountMan::createFilesystems() {
   while (!fstab.atEnd()) {
     s = t.readLine();
     s = s.simplifyWhiteSpace(); // remove TABs
-    if (s==QString::null || s=="") break;  // skip empty lines in fstab
+    if (s==QString::null || s=="") continue;  // skip empty lines in fstab
     // temp[0]==name, temp[1]==type, temp[2]==mount point, temp[3]==options
     // temp[4] is reserved for special cases, right now, only for supermount
  		bool remark=false;
@@ -144,7 +149,7 @@ bool KMountMan::createFilesystems() {
 		// now, we check if a remark was inserted in the line
 		for (int cnt=0; cnt<3; ++cnt)
 			if (temp[cnt][i]=="#" || temp[cnt][i].left(1)=="#") {
-				kdWarning() << "MountMan: found a remark in fstab, skipping the line." << endl;
+				//kdDebug() << "MountMan: found a remark in fstab, skipping the line." << endl;
         remark=true;
         break;
 			}
@@ -170,16 +175,16 @@ bool KMountMan::createFilesystems() {
   }
   --i; fstab.close();  // finished with it
   for (j=0; j<=i; ++j) {
-  	if (temp[0][j]=="" || temp[1][j]=="proc" || temp[1][j]=="/dev/pts" ||
-  			temp[1][j]=="swap" || temp[0][j]=="none" || temp[0][j]=="proc" ||
-        temp[0][j]=="swap" || temp[4][j]=="supermount") continue;
+  	if (temp[0][j]=="" || temp[0][j]=="tmpfs" || temp[0][j]=="none" || temp[0][j]=="proc" ||
+        temp[0][j]=="swap" || temp[1][j]=="proc" || temp[1][j]=="/dev/pts" ||	
+        temp[1][j]=="swap" || temp[4][j]=="supermount") continue;
   	++noOfFilesystems;
   }
   // now, create the main list
   QString forDebugOnly="";
   i=0; j=0;
   while (i<noOfFilesystems) {
-		if (temp[0][j]=="" || temp[1][j]=="proc" || temp[1][j]=="/dev/pts" ||
+		if (temp[0][j]=="" || temp[1][j]=="proc" || temp[1][j]=="/dev/pts" || temp[0][j]=="tmpfs" ||
   			temp[1][j]=="swap" || temp[0][j]=="none" || temp[0][j]=="proc" ||
         temp[0][j]=="swap" || temp[4][j]=="supermount") ++j;
     else {
@@ -321,14 +326,16 @@ void KMountMan::parseDfData(QString filename) {
     return;                   // make mt.man non-operational
   }
   QTextStream t( &f );        // use a text stream
-  QString s;
+  QString s,s2;
   s = t.readLine();  // read the 1st line - it's trash for us
   // now that we have a QString containing all the output of DF, let's get to work.
   int countFilesystems=0; // sucessfully found filesystems
   while (!t.eof()) {
 		bool newFS=false;
-    s = t.readLine();  // this is the important one!
+    s2 = s = t.readLine();  // this is the important one!
     temp=nextWord(s,' ');
+    // avoid adding unwanted filesystems to the list
+    if (temp=="tmpfs") continue;
     temp=followLink(temp);  // make sure DF gives us the true device and not a link
     fsData* loc=location(temp); // where is the filesystem located in our list?
     if (loc==0) {
@@ -359,12 +366,13 @@ void KMountMan::parseDfData(QString filename) {
     if (loc->mntPoint()!=temp) {
     	if (!newFS)
 				kdWarning() << "Mt.Man: according to DF, filesystem [" << loc->name() <<
-    		           		 "] is mounted on a point which is different from what's stated in /etc/fstab." << endl;
+    		           		 "] is mounted on " << temp << " and not on " << loc->mntPoint()<< endl;
       loc->setMntPoint(temp);  // DF knows best
     }
     loc->setMounted(true);
     ++countFilesystems;
   }
+
   Operational=Ready=true; // we are finished here
   if (countFilesystems>0) kdDebug() << "Mt.Man: Alive and kicking. " << endl;
    else {
@@ -388,6 +396,7 @@ void KMountMan::collectOutput(KProcess *p, char *buffer,int buflen) {
   if (!p) return; // don't collect data from unknown/undefined processes
   if (!outputBuffer) outputBuffer=new QString();  // create buffer if needed
   // add new buffer to the main output buffer
+
   for (int i=0; i<buflen; ++i) (*outputBuffer)+=buffer[i];
 }
 
@@ -410,7 +419,7 @@ void KMountMan::mount(QString mntPoint) {
   if (mountProc.normalExit())
     if (mountProc.exitStatus()==0) return; // incase of a normal exit
   // on any other case,report an error
-  KMessageBox::sorry(0,i18n("Unable to complete the mount.\n")+
+  KMessageBox::sorry(0,i18n("Unable to complete the mount.")+
     i18n("The error reported was:\n\n")+getOutput());
 }
 
@@ -433,7 +442,7 @@ void KMountMan::mount(fsData *p) {
 
   // don't allow mounting 'supermount' filesystems
   if (p->supermount) {
-    KMessageBox::information(0,i18n("Warning: you're trying to mount a 'supermount' filesystem.\nSupermount filesystems are (un)mounted automatically by linux\nupon insert/eject. This is usually a Linux-Mandrake feature.\nKrusader will not allow this, as it creates unpredictable behaviour."),i18n("Error"),"SupermountWarning");
+    KMessageBox::information(0,i18n("Warning: you're trying to mount a 'supermount' filesystem. Supermount filesystems are (un)mounted automatically by linux upon insert/eject. This is usually a Linux-Mandrake feature.Krusader will not allow this, as it creates unpredictable behaviour."),i18n("Error"),"SupermountWarning");
     return;
   }
   // connect all outputs to collectOutput, to be displayed later
@@ -443,13 +452,13 @@ void KMountMan::mount(fsData *p) {
   clearOutput();
   if (!mountProc.start(KProcess::Block,KProcess::Stderr)) {
     KMessageBox::error(0,
-      i18n("Unable to execute 'mount' !!!\ncheck that /bin/mount or /sbin/mount are availble"));
+      i18n("Unable to execute 'mount' !!! check that /bin/mount or /sbin/mount are availble"));
     return;
   }
   if (mountProc.normalExit())
     if (mountProc.exitStatus()==0) return; // incase of a normal exit
   // on any other case,report an error
-  KMessageBox::sorry(0,i18n("Unable to complete the mount.\n")+
+  KMessageBox::sorry(0,i18n("Unable to complete the mount.")+
     i18n("The error reported was:\n\n")+getOutput());
 }
 
@@ -472,7 +481,7 @@ void KMountMan::unmount(fsData *p) {
 
   // don't allow unmounting 'supermount' filesystems
   if (p->supermount) {
-    KMessageBox::information(0,i18n("Warning: you're trying to unmount a 'supermount' filesystem.\nSupermount filesystems are (un)mounted automatically by linux\nupon insert/eject. This is usually a Linux-Mandrake feature.\nKrusader will not allow this, as it creates unpredictable behaviour."),i18n("Error"),"SupermountWarning");
+    KMessageBox::information(0,i18n("Warning: you're trying to unmount a 'supermount' filesystem. Supermount filesystems are (un)mounted automatically by linux upon insert/eject. This is usually a Linux-Mandrake feature. Krusader will not allow this, as it creates unpredictable behaviour."),i18n("Error"),"SupermountWarning");
     return;
   }
   // connect outputs to collectOutput, to be displayed later
@@ -484,14 +493,14 @@ void KMountMan::unmount(fsData *p) {
   clearOutput();
   if (!umountProc.start(KProcess::NotifyOnExit,KProcess::Stderr)) {
     KMessageBox::error(0,
-      i18n("Unable to execute 'umount' !!!\ncheck that /bin/umount or /sbin/umount are availble"));
+      i18n("Unable to execute 'umount' !!! check that /bin/umount or /sbin/umount are availble"));
     return;
   } else while (umountProc.isRunning()) qApp->processEvents();
   krApp->stopWait();
   if (umountProc.normalExit())
     if (umountProc.exitStatus()==0) return; // incase of a normal exit
   // on any other case,report an error
-  KMessageBox::sorry(0,i18n("Unable to complete the un-mount.\n")+
+  KMessageBox::sorry(0,i18n("Unable to complete the un-mount.")+
     i18n("The error reported was:\n\n")+getOutput());
 }
 
@@ -511,7 +520,7 @@ void KMountMan::eject(QString mntPoint) {
   proc << "eject" << "\"" + mntPoint + "\"";
   proc.start(KProcess::Block);
   if (!proc.normalExit() || proc.exitStatus()!=0) // if we failed with eject
-    KMessageBox::information(0,i18n("Error ejecting device !\nYou need to have 'eject' in your path."),i18n("Error"),"CantExecuteEjectWarning");
+    KMessageBox::information(0,i18n("Error ejecting device ! You need to have 'eject' in your path."),i18n("Error"),"CantExecuteEjectWarning");
 }
 
 // returns true if the path is an ejectable mount point (at the moment CDROM)
@@ -584,4 +593,43 @@ void statsCollector::getData(QString path, fsData *data) {
   QDir().remove(tmpFile);
 }
 
+// a mountMan special version of KIO::convertSize, which deals
+// with large filesystems ==> >4GB, it actually recieve size in
+// a minimum block of 1024 ==> data is KB not bytes
+QString KMountMan::convertSize( unsigned long size )
+{
+    float fsize;
+    QString s;
+    // Tera-byte
+    if ( size >= 1073741824 )
+    {
+        fsize = (float) size / (float) 1073741824;
+        if ( fsize > 1024 ) // no name for something bigger than tera byte
+                            // let's call it Zega-Byte, who'll ever find out? :-)
+            s = i18n( "%1 ZB" ).arg( KGlobal::locale()->formatNumber(fsize / (float)1024, 1));
+        else
+            s = i18n( "%1 TB" ).arg( KGlobal::locale()->formatNumber(fsize, 1));
+    }
+    // Giga-byte
+    else if ( size >= 1048576 )
+    {
+        fsize = (float) size / (float) 1048576;
+        s = i18n( "%1 GB" ).arg( KGlobal::locale()->formatNumber(fsize, 1));
+    }
+    // Mega-byte
+    else if ( size > 1024 )
+    {
+        fsize = (float) size / (float) 1024;
+        s = i18n( "%1 MB" ).arg( KGlobal::locale()->formatNumber(fsize, 1));
+    }
+    // Kilo-byte
+    else
+    {
+        fsize = (float) size;
+        s = i18n( "%1 KB" ).arg( KGlobal::locale()->formatNumber(fsize, 0));
+    }
+    return s;
+}
+
 #include "kmountman.moc"
+
