@@ -45,6 +45,7 @@
 #include "kvfspanel.h"
 #include "../krslots.h"
 #include "../resources.h"
+#include <kdeversion.h>
 
 KFileList::KFileList(QWidget *parent, const char *name ) :
   KListView(parent,name) {
@@ -56,6 +57,7 @@ KFileList::KFileList(QWidget *parent, const char *name ) :
   stillScrolling=false;
   setMouseTracking(false);
   setDragAutoScroll(true);
+  setSelectionModeExt(KListView::FileManager);
   toolTip=false;
   toolTipItem=0;
 }
@@ -63,15 +65,30 @@ KFileList::KFileList(QWidget *parent, const char *name ) :
 /////////////////////////////////// slots ////////////////////////////////////////
 void KFileList::select(QString filter) {
   krConfig->setGroup("Look&Feel");
-  //////////////////////////////
+  bool markDirs = krConfig->readBoolEntry("Mark Dirs",_MarkDirs);
+  // ugly hack !!! see info in TODO regarding getMask gui
+  bool compareMode = filter.find(i18n("compare mode")) != -1;
+
   QListViewItem *temp=currentItem();
   QListViewItem *iterator=firstChild();
   while (iterator!=0) {
-    if (iterator->text(1)==QString("<DIR>") &&
-        !krConfig->readBoolEntry("Mark Dirs",_MarkDirs)) {
+    if (iterator->text(1)==QString("<DIR>") && !markDirs) {
       iterator=iterator->itemBelow();
       continue;
     }
+    // ugly hack - all of it!
+    if (compareMode) {
+      KRListItem::cmpColor color = KRListItem::none;
+      if (filter.find(i18n("Newer files")) != -1) color = KRListItem::newer;
+      if (filter.find(i18n("Older files")) != -1) color = KRListItem::older;
+      if (filter.find(i18n("Identical files")) != -1) color = KRListItem::identical;
+      if (filter.find(i18n("Exclusive files")) != -1) color = KRListItem::exclusive;
+      if (dynamic_cast<KRListItem*>(iterator)->getCompareModeID() == color) {
+        if (!iterator->isSelected()) ++numOfSelected;
+        iterator->setSelected(true);
+        iterator=iterator->itemBelow();
+      } else iterator=iterator->itemBelow();
+    } else
     if (QDir::match(filter,iterator->text(0))) {
       // we're increasing the number of selected files
       if (!iterator->isSelected()) ++numOfSelected;
@@ -231,13 +248,20 @@ void KFileList::keyPressEvent(QKeyEvent *e) {
     case Key_Delete :         // kill file
       SLOTS->deleteFiles();
       return;
+		case Key_Shift:
+		case Key_Control:
+			setSelectionModeExt(KListView::FileManager);
+			QListView::keyPressEvent(e);
+			break;
     default:
-      setSelectionMode(QListView::NoSelection);
+      if( e->state()==ControlButton || e->state()==ShiftButton )
+				setSelectionModeExt(KListView::FileManager);
+			else
+		  	setSelectionModeExt(KListView::NoSelection);
       QListView::keyPressEvent(e);
-      setSelectionMode(QListView::Extended);
+      setSelectionModeExt(KListView::FileManager);
       return;
   }
-  delete ne;
 }
 
 
@@ -293,7 +317,7 @@ void KFileList::viewportMouseMoveEvent(QMouseEvent *e) {
  	}
 }
 
-void KFileList::viewportMousePressEvent(QMouseEvent *e) {
+/*void KFileList::contentsMousePressEvent(QMouseEvent *e) {
   krConfig->setGroup("Look&Feel");
   mouseSelType=krConfig->readNumEntry("Mouse Selection",_MouseSelection);
   if (e->button()==RightButton) { // for right-click only
@@ -316,7 +340,7 @@ void KFileList::viewportMousePressEvent(QMouseEvent *e) {
     // function, to allow the swush thing
     switch (mouseSelType) {
       // classic-mode, let the list handle it
-      case 0 : QListView::viewportMousePressEvent(e);
+      case 0 : KListView::contentsMousePressEvent(e);
                break;
       // left-click selection, just make it current
       case 1 : if (i) setCurrentItem(i);
@@ -334,7 +358,7 @@ void KFileList::viewportMousePressEvent(QMouseEvent *e) {
     QListViewItem *i = itemAt(e->pos());
     switch (mouseSelType) {
       // classic-mode, let the list handle it
-      case 0 : QListView::viewportMousePressEvent(e);
+      case 0 : KListView::contentsMousePressEvent(e);
                break;
       // left-key selection, so don't do nothing here
       case 1 : emit mouseButtonPressed(e->button(),i, e->pos(), 1);
@@ -347,7 +371,7 @@ void KFileList::viewportMousePressEvent(QMouseEvent *e) {
   }
 }
 
-void KFileList::viewportMouseReleaseEvent(QMouseEvent *e) {
+void KFileList::contentsMouseReleaseEvent(QMouseEvent *e) {
   krConfig->setGroup("Look&Feel");
   mouseSelType=krConfig->readNumEntry("Mouse Selection",_MouseSelection);
   if (e->button()==RightButton) { // for right-click only
@@ -357,7 +381,7 @@ void KFileList::viewportMouseReleaseEvent(QMouseEvent *e) {
     if (!i) return; // did the user click on a item in the list?
     switch (mouseSelType) {
       // classic-mode, the listview handles it
-      case 0 : QListView::viewportMouseReleaseEvent(e);
+      case 0 : QListView::contentsMouseReleaseEvent(e);
                break;
       // left-click selection, do nothing ... it's already current
       case 1 :  break;
@@ -377,7 +401,7 @@ void KFileList::viewportMouseReleaseEvent(QMouseEvent *e) {
     if (!i) return; // did the user click on a item in the list?
     switch (mouseSelType) {
       // classic-mode, the listview handles it
-      case 0 : QListView::viewportMouseReleaseEvent(e);
+      case 0 : QListView::contentsMouseReleaseEvent(e);
                break;
       // right-click selection mode
       case 2 : break;
@@ -391,9 +415,9 @@ void KFileList::viewportMouseReleaseEvent(QMouseEvent *e) {
                break;
     }
   }
-}
+} */
 
-void KFileList::checkForRightClickMenu() {
+/*void KFileList::checkForRightClickMenu() {
   if (stillPressed) { // if the right-button is still pressed
     // check if we moved enough - assume "swush"
     int delta = QCursor::pos().y() - (pressY + yDelta);
@@ -418,7 +442,7 @@ void KFileList::checkForRightClickMenu() {
     QPoint temp=mapToGlobal(p);
     emit rightClickMenu(i,temp);
   }
-}
+}*/
 
 QListViewItem* KFileList::firstUnmarkedAboveCurrent(){
   QListViewItem *iterator=currentItem()->itemAbove();
