@@ -37,6 +37,7 @@
 #include <qdragobject.h>
 #include <qpopupmenu.h>
 #include <qtimer.h>
+#include <qregexp.h>
 // KDE includes
 #include <kmessagebox.h>
 #include <klocale.h>
@@ -52,6 +53,8 @@
 #include <kmessagebox.h>
 #include <kstddirs.h>
 #include <kglobalsettings.h>
+#include <kdeversion.h>
+#include <qtabbar.h>
 // Krusader includes
 #include "../krusader.h"
 #include "../krslots.h"
@@ -119,15 +122,9 @@ ListPanel::ListPanel(QWidget *parent, const bool mirrored, const char *name ) :
   totals->setLineWidth(1);		// a nice 3D touch :-)
   QWhatsThis::add(totals,i18n("The totals bar shows how much files exist, how many did you select and the bytes math"));
 
-	origin = new QPushButton("",this);
-	krConfig->setGroup("Look&Feel");
-	origin->setFont(krConfig->readFontEntry("Filelist Font",_FilelistFont));
-	origin->font().setBold(true);
-	origin->font().setPointSize(origin->font().pointSize()+2);
-  origin->setBackgroundMode(PaletteBackground);
-		// pressing the origin bar sets focus
+  origin = new QPushButton("", this);
   QWhatsThis::add(origin,i18n("This shows the full path to your current directory"));
-	connect(origin,SIGNAL(clicked()),this,SLOT(slotFocusOnMe()));
+  connect(origin,SIGNAL(clicked()),this,SLOT(slotFocusOnMe()));
 
   fileList = new KFileList(this);
   krConfig->setGroup("Look&Feel");
@@ -176,8 +173,9 @@ ListPanel::ListPanel(QWidget *parent, const bool mirrored, const char *name ) :
 		// a change in the selection needs to update totals
 	connect(fileList, SIGNAL(selectionChanged()), this,	SLOT(slotUpdateTotals()));
     // right-click menu
-  connect(fileList, SIGNAL(rightClickMenu(QListViewItem*,QPoint)), this,
-          SLOT(popRightClickMenu(QListViewItem*,QPoint)));
+  connect(fileList, SIGNAL(contextMenu(KListView *, QListViewItem*,const QPoint&)), this,
+          SLOT(popRightClickMenu(KListView *,QListViewItem*,const QPoint&)));
+
 		// conncet krusder status bar with mouse over event...
 	connect(this,SIGNAL(signalStatus(QString)),
 					krApp, SLOT(statusBarUpdate(QString)));
@@ -192,16 +190,17 @@ ListPanel::ListPanel(QWidget *parent, const bool mirrored, const char *name ) :
 					SLOT(slotSetActivePanel(KVFSPanel *)) );
 
     // when the BookMan asks to refresh bookmarks...
-  connect(krBookMan, SIGNAL(refreshBookmarks()), this, SLOT(slotRefreshBookmarks()));							
-		// finish the layout
+  connect(krBookMan, SIGNAL(refreshBookmarks()), this, SLOT(slotRefreshBookmarks()));
+
+  // finish the layout
 	layout->addMultiCellWidget(origin,0,0,0,1);
 	if (mirrored) {
 		layout->addWidget(status,1,0);
 		layout->addWidget(bookmarkList,1,1);
-		
+
 	} else {
 		layout->addWidget(status,1,1);
-		layout->addWidget(bookmarkList,1,0);	
+		layout->addWidget(bookmarkList,1,0);
 	}
 	layout->addMultiCellWidget(fileList,2,2,0,1);
 	layout->addMultiCellWidget(totals,3,3,0,1);
@@ -292,6 +291,7 @@ void ListPanel::slotFocusOnMe(){		 // give this VFS the focus (the path bar)
                           || files->vfs_getType()=="ftp");
   krCompare->setEnabled(otherPanel->type=="list");    // compare by content
   krCompareDirs->setEnabled(otherPanel->type=="list");// compare dirs
+	krMultiRename->setEnabled(files->vfs_getType()=="normal");
 }
 
 // overload this to control the NAME column resize
@@ -335,16 +335,17 @@ void ListPanel::start(bool left) {
 	  else virtualPath = getcwd(0,0);
 	}
 	
-	QFileInfo qfi(virtualPath);
+/*	QFileInfo qfi(virtualPath);
 	if (!qfi.isDir() || !qfi.exists()){
 	  virtualPath = "/";
 	  QString side = (left ? i18n("left") : i18n("right"));
-	  KMessageBox::error(krApp,i18n("The ")+side+i18n(" panel start path is invalid\nCheck your Konfigurator"));
+	  //KMessageBox::error(krApp,i18n("The ")+side+i18n(" panel start path is invalid. Check your Konfigurator"));
   }	
 	
 	realPath = virtualPath;
-	
+*/	
 	files = new normal_vfs(virtualPath,this);
+  openUrl(virtualPath);
 }
 
 void ListPanel::slotStartUpdate(){
@@ -387,7 +388,8 @@ void ListPanel::slotUpdate(){
 	
 	// if we are not at the root add the ".." entery
 	QString origin = files->vfs_getOrigin();
-	if( origin.right(1)!="/" && !((files->vfs_getType()=="ftp")&& origin.find('/',6)==-1) ) {
+	if( origin.right(1)!="/" && !((files->vfs_getType()=="ftp")&&
+      origin.find('/',origin.find(":/")+3)==-1) ) {
 		QListViewItem * item=new KRListItem(fileList,"..","<DIR>");
 		item->setPixmap(0,FL_LOADICON("up"));
 	  item->setSelectable(false);
@@ -398,18 +400,18 @@ void ListPanel::slotUpdate(){
 		size =  KRpermHandler::parseSize(vf->vfile_getSize());
 		name =  vf->vfile_getName();
 		bool isDir = vf->vfile_isDir();
-		cmpColor color = none;
+		KRListItem::cmpColor color = KRListItem::none;
 		if( otherPanel->type == "list" && compareMode ){
 		  vfile* ovf = otherPanel->files->vfs_search(vf->vfile_getName());
-		  if (ovf == 0 ) color = exclusive;  // this file doesn't exist on the other panel
+		  if (ovf == 0 ) color = KRListItem::exclusive;  // this file doesn't exist on the other panel
 		  else{ // if we found such a file
         QString date1 = KRpermHandler::date2qstring(vf->vfile_getDateTime());
         QString date2 = KRpermHandler::date2qstring(ovf->vfile_getDateTime());
-        if (date1 > date2) color = newer; // this file is newer than the other
+        if (date1 > date2) color = KRListItem::newer; // this file is newer than the other
         else
-        if (date1 < date2) color = older; // this file is older than the other
+        if (date1 < date2) color = KRListItem::older; // this file is older than the other
         else
-        if (date1 == date2) color = identical; // the files are the same
+        if (date1 == date2) color = KRListItem::identical; // the files are the same
 		  }
 		}
 		
@@ -426,7 +428,7 @@ void ListPanel::slotUpdate(){
 
 		item = new KRListItem(fileList,item,name,
 				isDir ? QString("<DIR>") : size,
-		    vf->vfile_getDateTime(),"","","");
+		    vf->vfile_getDateTime(),"","","",color);
 
   	switch (vf->vfile_isReadable()){
       case ALLOWED_PERM: item->setText(3,QString("r")); break;
@@ -434,12 +436,12 @@ void ListPanel::slotUpdate(){
       case NO_PERM:      item->setText(3,QString("-")); break;
     }
   	switch (vf->vfile_isWriteable()){
-      case ALLOWED_PERM: item->setText(4,QString("r")); break;
+      case ALLOWED_PERM: item->setText(4,QString("w")); break;
       case UNKNOWN_PERM: item->setText(4,QString("?")); break;
       case NO_PERM:      item->setText(4,QString("-")); break;
     }
   	switch (vf->vfile_isExecutable()){
-      case ALLOWED_PERM: item->setText(5,QString("r")); break;
+      case ALLOWED_PERM: item->setText(5,QString("x")); break;
       case UNKNOWN_PERM: item->setText(5,QString("?")); break;
       case NO_PERM:      item->setText(5,QString("-")); break;
     }
@@ -483,12 +485,12 @@ void ListPanel::slotUpdateTotals() {
 	}
 
 	totalsLine = QString("%1 "+i18n("out of")+" %2 "+i18n("selected")+", %3 "+i18n("out of")+
-					" %4").arg(selectedNo).arg(totalNo).arg(KIO::convertSize64(selectedSize)).
-					arg(KIO::convertSize64(totalSize));
+					" %4").arg(selectedNo).arg(totalNo).arg(KIO::convertSize(selectedSize)).
+					arg(KIO::convertSize(totalSize));
 	totals->setText(totalsLine);
 }
 
-QPixmap ListPanel::getIcon(vfile* vf, cmpColor color){
+QPixmap ListPanel::getIcon(vfile* vf, KRListItem::cmpColor color){
 	krConfig->setGroup("Advanced");
 	//////////////////////////////
 	QPixmap icon;
@@ -514,17 +516,17 @@ QPixmap ListPanel::getIcon(vfile* vf, cmpColor color){
   }
 
   // color-coding for compare mode
-  if (color != none) {
+  if (color != KRListItem::none) {
     QPixmap block;
     switch (color) {
-      case exclusive : block = QPixmap(blue_xpm);
-                     break;
-      case newer :   block = QPixmap(green_xpm);
-                     break;
-      case older :   block = QPixmap(red_xpm);
-                     break;
-      case identical  :   block = QPixmap(yellow_xpm);
-                     break;
+      case KRListItem::exclusive : block = QPixmap(blue_xpm);
+                                   break;
+      case KRListItem::newer     : block = QPixmap(green_xpm);
+                                   break;
+      case KRListItem::older     : block = QPixmap(red_xpm);
+                                   break;
+      case KRListItem::identical : block = QPixmap(yellow_xpm);
+                                   break;
     }
 		
 		bitBlt (&icon,icon.width()-11,0,&block,0,21,10,11,CopyROP,false);
@@ -562,7 +564,7 @@ void ListPanel::slotChangeStatus(QListViewItem *i){
       	text += "  ";
       	text += tmp;
   		} else if ( S_ISREG( m_fileMode ) ){
-      	text = QString("%1 (%2)").arg(text2).arg( KIO::convertSize64( mySize ) );
+      	text = QString("%1 (%2)").arg(text2).arg( KIO::convertSize( mySize ) );
       	text += "  ";
       	text += comment;
   		} else if ( S_ISDIR ( m_fileMode ) ){
@@ -596,8 +598,8 @@ void ListPanel::slotGetStats(QString path) {
     return;
 	}
 	
-	if (path.contains("://")) {
-    status->setText(i18n("No space information on remote filesystems"));
+	if (path.contains(":/")) {
+    status->setText(i18n("No space information on non-local filesystems"));
     return;
   }
 
@@ -827,7 +829,8 @@ void ListPanel::startDragging(int mode) {
 }
 
 // pops a right-click menu for items
-void ListPanel::popRightClickMenu(QListViewItem* item,QPoint loc) {
+void ListPanel::popRightClickMenu(KListView *kl, QListViewItem* item,const QPoint &loc2) {
+  QPoint loc = loc2;
   // these are the values that will always exist in the menu
   #define OPEN_ID       90
   #define OPEN_WITH_ID  91
@@ -886,7 +889,7 @@ void ListPanel::popRightClickMenu(QListViewItem* item,QPoint loc) {
       KService::Ptr service = offers[i].service();
       if( service->isValid() && service->type()=="Application" ) {
         openWith.insertItem( service->name(),SERVICE_LIST_ID+i );
-        openWith.changeItem(SERVICE_LIST_ID+i,service->pixmap(0,16),service->name());
+        openWith.changeItem(SERVICE_LIST_ID+i,service->pixmap(KIcon::Small),service->name());
       }
     }
     openWith.insertSeparator();
@@ -936,11 +939,9 @@ void ListPanel::popRightClickMenu(QListViewItem* item,QPoint loc) {
   }
 
   // send by mail (only for KDE version >= 2.2.0)
-	#if KDE_VERSION >= 220
   if (Krusader::supportedTools().contains("MAIL") && !vf->vfile_isDir()) {
     popup.insertItem(i18n("Send by email"), SEND_BY_EMAIL);
   }
-  #endif
   // PROPERTIES
   popup.insertSeparator();
   krProperties->plug(&popup);
@@ -954,12 +955,13 @@ void ListPanel::popRightClickMenu(QListViewItem* item,QPoint loc) {
   switch (result) {
     case -1 : return;     // the user clicked outside of the menu
     case OPEN_ID :        // Open/Run
-      new KFileOpenWithHandler();
+      //new KFileOpenWithHandler();
       iterator=fileList->firstChild();
       while (iterator) {
         if (iterator->isSelected()) {
-    	    u.setPath(files->vfs_getFile(fileList->getFilename(iterator)));
-    		  new KRun(u,vf->vfile_getMode() );
+          QString fname = fileList->getFilename(iterator);
+    	    u.setPath(files->vfs_getFile(fname));
+          KRun::runURL(u, (files->vfs_search(fname))->vfile_getMime());
         }
         iterator=iterator->itemBelow();
       }
@@ -982,18 +984,18 @@ void ListPanel::popRightClickMenu(QListViewItem* item,QPoint loc) {
     case SHRED_ID :
       if (KMessageBox::warningContinueCancel(krApp,
           i18n("Are you sure you want to shred ")+"\""+fileList->getFilename(item)+"\""+
-          " ?\nOnce shred, the file is gone forever !!!",
-          QString::null,"Shred") == KMessageBox::Continue )
+          " ? Once shred, the file is gone forever !!!",
+          QString::null,KStdGuiItem::cont(),"Shred") == KMessageBox::Continue )
         KShred::shred(files->vfs_getFile(fileList->getFilename(item)));
       break;
     case OPEN_KONQ_ID :   // open in konqueror
       kapp->startServiceByDesktopName("konqueror",files->vfs_getFile(fileList->getFilename(item)));
       break;
     case CHOOSE_ID :      // Other...
-      new KFileOpenWithHandler();
+      //new KFileOpenWithHandler();
       u.setPath(files->vfs_getFile(fileList->getFilename(item)));
       lst.append(u);
-      KOpenWithHandler::getOpenWithHandler()->displayOpenWithDialog(lst);
+      KRun::displayOpenWithDialog(lst);
       break;
     case MOUNT_ID :
       krMtMan.mount(files->vfs_getFile(fileList->getFilename(item)));
@@ -1090,7 +1092,8 @@ void ListPanel::openUrl( QString path, QString file ){
 		refresh(path);
 	}	
 	// remote file systems
-	else if( path.contains("://") ){
+	else if( path.contains(":/") ){
+		
 		func->changeVFS("ftp",path);
 	}
 	else{ // local directories
