@@ -35,12 +35,14 @@
 #include <klocale.h>
 #include <kio/jobclasses.h>
 #include <kprocess.h>
+#include <kpropertiesdialog.h>
 #include <kopenwith.h>
 #include <kmessagebox.h>
 #include <kcursor.h>
 #include <kstddirs.h>
 #include <ktempfile.h>
 #include <kurl.h>
+#include <krun.h>
 #include <klineeditdlg.h>
 // Krusader Includes
 #include "panelfunc.h"
@@ -57,7 +59,7 @@
 #include "../Dialogs/krdialogs.h"
 #include "../Dialogs/krpleasewait.h"
 #include "../Dialogs/krspwidgets.h"
-#include "../KViewer/kviewer.h"
+#include "../KViewer/krviewer.h"
 #include "../MountMan/kmountman.h"
 #include "../resources.h"
 
@@ -71,7 +73,7 @@ void ListPanelFunc::goBack(){
   if(backStack.isEmpty()) return;
 	
   if(backStack.last() == "//WARNING//"){
-    KMessageBox::information(0, i18n("Can't re-enter archive.\nGoing to the nearest path"), QString::null, "BackArchiveWarning");
+    KMessageBox::information(0, i18n("Can't re-enter archive. Going to the nearest path"), QString::null, "BackArchiveWarning");
     backStack.remove(backStack.fromLast()); //remove the //WARNING// entry
   }
   QString path = backStack.last();
@@ -96,7 +98,7 @@ void ListPanelFunc::redirectLink(){
 	QString file = panel->files->vfs_getFile( vf->vfile_getName() );
 	QString currentLink = vf->vfile_getSymDest();
 	if ( currentLink.isEmpty() ){
-		KMessageBox::sorry(krApp,i18n("The current file is not a link,\nso i can't redirect it.") );
+		KMessageBox::sorry(krApp,i18n("The current file is not a link, so i can't redirect it.") );
 	  return;
 	}
 
@@ -137,7 +139,7 @@ void ListPanelFunc::krlink(bool sym){
 
 	// if the name is already taken - quit
 	if (panel->files->vfs_search(linkName) != 0){
-		KMessageBox::sorry(krApp,i18n("A directory or a file with this file\nalready exists."));
+		KMessageBox::sorry(krApp,i18n("A directory or a file with this file already exists."));
 		return;
 	}
 	
@@ -166,12 +168,10 @@ void ListPanelFunc::view(){
 	// let's get the file name (without the full path)
 	QString fileName = panel->getCurrentName();
 	if (fileName.isNull()) return;
-	// now, we need it's mimetype, thanks to the killer vFile
-	QString mimetype = panel->files->vfs_search(fileName)->vfile_getMime();
 	// at this point, let's take the full path
 	fileName = panel->files->vfs_getFile(fileName);
   // and call KViewer.
-  KViewer::view(fileName,mimetype);
+  KrViewer::view(fileName);
   // nothing more to it!	
 }
 
@@ -197,7 +197,7 @@ void ListPanelFunc::editFile(){
 	if(krConfig->readBoolEntry("Permission Check",_PermCheck) &&
      panel->files->vfs_getType() == "normal" &&
 	  !panel->files->vfs_search(name)->vfile_isReadable()){
-		KMessageBox::sorry(krApp,i18n("You do not have permission \nto read ")+name);
+		KMessageBox::sorry(krApp,i18n("You do not have permission to read ")+name);
 	  return;
 	}
 	
@@ -209,9 +209,13 @@ void ListPanelFunc::editFile(){
 	KProcess proc;
 	krConfig->setGroup("General");
 	QString edit = krConfig->readEntry("Editor",_Editor);
-	proc << edit << panel->files->vfs_getFile(name);
-  if(!proc.start(KProcess::DontCare))
-    KMessageBox::sorry(krApp,i18n("Can't open ")+"\""+edit+"\"");
+  if( edit == "internal editor" )
+     KrViewer::edit(panel->files->vfs_getFile(name));
+  else {
+    proc << edit << panel->files->vfs_getFile(name);
+    if(!proc.start(KProcess::DontCare))
+      KMessageBox::sorry(krApp,i18n("Can't open ")+"\""+edit+"\"");
+  }
 }
 
 void ListPanelFunc::moveFiles(){
@@ -310,7 +314,7 @@ void ListPanelFunc::rename(){
   if(krConfig->readBoolEntry("Permission Check",_PermCheck)){
 	  if(!panel->files->vfs_search(fileName)->vfile_isWriteable() ||
 	     !panel->files->isWritable){
-		  KMessageBox::sorry(krApp,i18n("You do not have permission \nto rename ")+fileName);
+		  KMessageBox::sorry(krApp,i18n("You do not have permission to rename ")+fileName);
 	    return;
     }
   } 			
@@ -323,7 +327,7 @@ void ListPanelFunc::rename(){
 	if ( !ok || newName==fileName ) return;
 	// if the name is already taken - quit
 	if (panel->files->vfs_search(newName) != 0){
-		KMessageBox::sorry(krApp,i18n("A directory or a file with this name\nalready exists."));
+		KMessageBox::sorry(krApp,i18n("A directory or a file with this name already exists."));
 		return;
 	}	
 	panel->nameToMakeCurrent = newName;
@@ -350,7 +354,7 @@ void ListPanelFunc::mkdir(){
 	
 	// if the name is already taken - quit
 	if (panel->files->vfs_search(dirName) != 0){
-		KMessageBox::sorry(krApp,i18n("A directory or a file with this file\nalready exists."));
+		KMessageBox::sorry(krApp,i18n("A directory or a file with this file already exists."));
 		return;
 	}	
 	panel->nameToMakeCurrent = dirName;
@@ -472,7 +476,7 @@ void ListPanelFunc::deleteFiles() {
 	    b = i18n("&Delete");
 	  }
 	  // show message
-	  if(KMessageBox::warningContinueCancel(krApp,i18n("Are you sure you want to\n")+s
+	  if(KMessageBox::warningContinueCancel(krApp,i18n("Are you sure you want to ")+s
 	    ,QString::null,b)
 	    == KMessageBox::Cancel ) return;
   }
@@ -532,7 +536,7 @@ void ListPanelFunc::deleteFiles() {
 // this is done when you double click on a file
 void ListPanelFunc::execute(QListViewItem *i) {
 	if (!i) return;
-	
+
 	QString name=panel->getFilename(i);
 	if(name==".."){
 		dirUp();
@@ -542,12 +546,12 @@ void ListPanelFunc::execute(QListViewItem *i) {
 	vfile *vf=panel->files->vfs_search(name);
 	if(vf == 0) return;
 	QString origin= panel->files->vfs_getOrigin();
-	
+
 	// verify read permissions
 	krConfig->setGroup("Advanced");
 	if(krConfig->readBoolEntry("Permission Check",_PermCheck)){
     if(!vf->vfile_isReadable()){
-      KMessageBox::sorry(krApp,i18n("You don't have premission to\naccess this Directory / File !"));
+      KMessageBox::sorry(krApp,i18n("You don't have premission to access this Directory / File !"));
 	    return;
     }
 	}
@@ -561,20 +565,29 @@ void ListPanelFunc::execute(QListViewItem *i) {
 	  panel->nameToMakeCurrent = QString::null;
 		panel->refresh(origin);
 	}
-	else if(panel->files->vfs_getType() == "ftp"){
-		QString tmp = i18n("If you want to execute %1,\nTransfer it first to your computer.").arg(name);
-    KMessageBox::sorry( krApp, tmp);
+	/*
+	else {
+		if(panel->files->vfs_getType() == "ftp" ){
+	  	if( !vf->vfile_isSymLink() ){
+		  	QString tmp = i18n("If you want to execute %1,\nTransfer it first to your computer.").arg(name);
+      	KMessageBox::sorry( krApp, tmp);
+    }
+	  else {
+			origin+="/"+name;
+	  	panel->nameToMakeCurrent = QString::null;
+			panel->refresh(origin);
+		}
 	}
+	*/
 	else if( KRarcHandler::arcHandled(type)){
   	changeVFS( type,panel->files->vfs_getFile(vf->vfile_getName()) );
 	  // add warning to the backStack
 	  if(backStack.last() != "//WARNING//" ) backStack.append("//WARNING//");
 	}
   else {
-		new KFileOpenWithHandler();
-	  KURL url;
-	  url.setPath(panel->files->vfs_getFile(name));
-		new KRun(url,vf->vfile_getMode() );
+      KURL url;
+      url.setPath(panel->files->vfs_getFile(name));
+      KRun::runURL(url, vf->vfile_getMime());
   }
 }
 
@@ -582,10 +595,12 @@ void ListPanelFunc::dirUp(){
 	QString origin= panel->virtualPath;
 	
 	//do we need to change vfs ?
-	if( origin.right(1) == "\\" || panel->files->vfs_error() ){ //yes
+	if( origin.right(1) == "\\"   ||
+      panel->files->vfs_error() ||
+      (origin.contains(":/") && origin.right(1)=="/")) { //yes
 	  delete panel->files;
-	  panel->files = panel->vfsStack->pop();
-	  panel->files->blockSignals(false);
+    panel->files = panel->vfsStack->pop();
+    panel->files->blockSignals(false);
 		// make the current archive the current item on the new list
 		panel->nameToMakeCurrent =
 			origin.mid(origin.findRev('/')+1,origin.length()-origin.findRev('/')-2);
@@ -593,18 +608,17 @@ void ListPanelFunc::dirUp(){
 	  return;
 	}
 	
-	// Do nothing (instead of error message) when user clicks on ".." in ftp root:
-	// Patch by "Milan Brabec" <mbrabec@volny.cz>
-	if(origin.startsWith("ftp://")&&origin.find('/',6)==-1) return;
-  	
-	// remove one dir from the path
+  // remove one dir from the path
 	origin.truncate(origin.findRev('/'));
 		
 	// make the current dir the current item on the new list
 	panel->nameToMakeCurrent = panel->virtualPath.right(panel->virtualPath.length()-origin.length()-1 );
 	
 	// check the '/' case
-	if (origin=="") origin="/";
+	if ( origin=="" ) origin="/";
+  // and the '/' case for urls
+  if ( origin.contains(":/") && origin.find("/",origin.find(":/")+3)==-1 )
+		origin=origin+"/";
 	
 	// change dir..
 	panel->refresh(origin);
@@ -656,7 +670,7 @@ void ListPanelFunc::pack() {
 		  !panel->files->vfs_search(*name)->vfile_isReadable()){
 		  if(skipAll) name = fileNames.remove(name);
 		  else switch( KMessageBox::warningYesNoCancel(krApp,
-	        i18n("You do not have permission \nto pack ")+(*name).latin1(),
+	        i18n("You do not have permission to pack ")+(*name).latin1(),
 	        QString::null,i18n("&Skip"),i18n("Skip &All")) ){
 	        case KMessageBox::Cancel : return; // stop operation
           case KMessageBox::No     : skipAll = true;
@@ -690,14 +704,14 @@ void ListPanelFunc::pack() {
   krConfig->setGroup("Advanced");
 	if(krConfig->readBoolEntry("Permission Check",_PermCheck) &&
     (packToOtherPanel && !panel->otherPanel->files->isWritable) || !QFileInfo(PackGUI::destination).isWritable()){
-    KMessageBox::sorry(krApp,i18n("You don't have write permissions\nto the destination directory"));
+    KMessageBox::sorry(krApp,i18n("You don't have write permissions to the destination directory"));
 	  return;
   }
 
   if(PackGUI::type != "zip" && QFileInfo(arcFile).exists()){
     if(KMessageBox::warningContinueCancel(krApp,
 	        i18n("The Archive ")+PackGUI::filename+"."+PackGUI::type+
-	        i18n("\nalready exists, Do you want to overwrite the archive\n")+
+	        i18n(" already exists, Do you want to overwrite the archive ")+
 	        i18n("(all data in previous archive will be lost)"),QString::null,i18n("&Overwite"))
 	        == KMessageBox::Cancel ) return; // stop operation
   }
@@ -772,19 +786,19 @@ void ListPanelFunc::unpack(){
   krConfig->setGroup("Advanced");
 	if(krConfig->readBoolEntry("Permission Check",_PermCheck) &&
     (packToOtherPanel && !panel->otherPanel->files->isWritable) || !QFileInfo(dest).isWritable()){
-    KMessageBox::sorry(krApp,i18n("You don't have write permissions\nto the destination directory"));
+    KMessageBox::sorry(krApp,i18n("You don't have write permissions to the destination directory"));
 	  return;
   }
 
 
-  for(int i=0; i<fileNames.count(); ++i){
+  for(unsigned int i=0; i<fileNames.count(); ++i){
     QString arcName = fileNames[i];
     if (arcName.isNull()) return;
     if (arcName=="..") return; // safety
 
     if(krConfig->readBoolEntry("Permission Check",_PermCheck) &&
 	    !panel->files->vfs_search(arcName)->vfile_isReadable()){
-		  KMessageBox::sorry(krApp,i18n("You do not have permission\nto unpack ")+(arcName));
+		  KMessageBox::sorry(krApp,i18n("You do not have permission to unpack ")+(arcName));
 	    return;
     }
 
@@ -823,7 +837,7 @@ void ListPanelFunc::calcSpace(){
   QString msg;
   QString fileName=((names.count()==1) ? (i18n("Name: ")+names.first()+"\n") : QString(""));
   msg=fileName+i18n("Total occupied space: %1\nin %2 directories and %3 files").
-      arg(KIO::convertSize64(totalSize)).arg(totalDirs).arg(totalFiles);
+    arg(KIO::convertSize(totalSize)).arg(totalDirs).arg(totalFiles);
   KMessageBox::information(krApp,msg.latin1());
 }
 
@@ -857,7 +871,7 @@ void ListPanelFunc::properties() {
 	KURL::List* urls = panel->files->vfs_getFiles( &names );
 	KFileItemList fi;
 	
-  for(int i=0 ; i < urls->count() ; ++i ) {
+  for(unsigned int i=0 ; i < urls->count() ; ++i ) {
   	fi.append(new KFileItem( (mode_t)-1,(mode_t)-1,*(urls->at(i)) ));
   }
 	// create a new url and get the file's mode
@@ -910,7 +924,7 @@ void TreePanelFunc::mkdir(){
 	
 	// if the name is already taken - quit
 	if (QDir(panel->files->vfs_origin+"/"+dirName).exists()){
-		KMessageBox::sorry(krApp,i18n("A directory or a file with this file\nalready exists."));
+		KMessageBox::sorry(krApp,i18n("A directory or a file with this file already exists."));
 		return;
 	}	
 	// as always - the vfs do the job
@@ -944,7 +958,7 @@ void TreePanelFunc::deleteFiles(){
 	    b = i18n("&Delete");
 	  }
 	  // show message
-	  if(KMessageBox::warningContinueCancel(krApp,i18n("Are you sure you want to\n")+s
+	  if(KMessageBox::warningContinueCancel(krApp,i18n("Are you sure you want to ")+s
 	    ,QString::null,b)
 	    == KMessageBox::Cancel ) return;
   }
@@ -955,7 +969,7 @@ void TreePanelFunc::deleteFiles(){
 	dir.setPath( panel->files->vfs_origin );
 	if ( dir.count() > 2 && krConfig->readBoolEntry("Confirm Unempty Dir",_ConfirmUnemptyDir) )
 	  if( KMessageBox::warningContinueCancel( krApp,
-		  i18n("Directory ")+(panel->files->vfs_origin)+i18n(" is not empty !\nAre you sure ? "),
+		  i18n("Directory ")+(panel->files->vfs_origin)+i18n(" is not empty ! Are you sure ? "),
 			QString::null,i18n("&Delete") ) == KMessageBox::Cancel) return;
 				
   // let the vfs do the job...
@@ -969,7 +983,7 @@ void TreePanelFunc::rename(){
 
   if(krConfig->readBoolEntry("Permission Check",_PermCheck)){
 	  if( !panel->files->isWritable ){
-		  KMessageBox::sorry(krApp,i18n("You do not have permission \nto rename ")+fileName);
+		  KMessageBox::sorry(krApp,i18n("You do not have permission to rename ")+fileName);
 	    return;
     }
   } 			
@@ -983,7 +997,7 @@ void TreePanelFunc::rename(){
   // if the name is already taken - quit
 	QString path = panel->files->vfs_origin.left(panel->files->vfs_origin.findRev('/')-1);
 	if ( QDir(path+"/"+newName).exists() ) {
-		KMessageBox::sorry(krApp,i18n("A directory with this name\nalready exists."));
+		KMessageBox::sorry(krApp,i18n("A directory with this name already exists."));
 		return;
 	}	
 	// as always - the vfs do the job
@@ -1011,7 +1025,7 @@ void TreePanelFunc::copyFiles(){
 	krConfig->setGroup("Advanced");
 	if(krConfig->readBoolEntry("Permission Check",_PermCheck) &&
     !panel->files->supportMoveFrom){  // vfs_supportMoveFrom == readable
-	  KMessageBox::sorry(krApp,i18n("You do not have permission \nto move ")+(panel->files->vfs_origin));
+	  KMessageBox::sorry(krApp,i18n("You do not have permission to move ")+(panel->files->vfs_origin));
 	  return; // stop operation
 	}
 
@@ -1067,7 +1081,7 @@ void TreePanelFunc::moveFiles(){
 	krConfig->setGroup("Advanced");
 	if(krConfig->readBoolEntry("Permission Check",_PermCheck) &&
     !panel->files->supportMoveFrom){  // vfs_supportMoveFrom == readable
-	  KMessageBox::sorry(krApp,i18n("You do not have permission\nto move ")+(panel->files->vfs_origin));
+	  KMessageBox::sorry(krApp,i18n("You do not have permission to move ")+(panel->files->vfs_origin));
 	  return; // stop operation
 	}
 	
@@ -1106,7 +1120,7 @@ void TreePanelFunc::pack() {
 	if(krConfig->readBoolEntry("Permission Check",_PermCheck) &&
 	   !panel->files->supportMoveFrom){
 	
-	  KMessageBox::sorry(krApp,i18n("You do not have permission\nto pack ")+(panel->files->vfs_origin));
+	  KMessageBox::sorry(krApp,i18n("You do not have permission to pack ")+(panel->files->vfs_origin));
 	  return; // stop operation
   }
 
@@ -1150,13 +1164,13 @@ void TreePanelFunc::pack() {
   krConfig->setGroup("Advanced");
 	if(krConfig->readBoolEntry("Permission Check",_PermCheck) &&
     (packToOtherPanel && !panel->otherPanel->files->isWritable) || !QFileInfo(PackGUI::destination).isWritable()){
-    KMessageBox::sorry(krApp,i18n("You don't have write permissions\nto the destination directory"));
+    KMessageBox::sorry(krApp,i18n("You don't have write permissions to the destination directory"));
 	  return;
   }
 
   if(PackGUI::type != "zip" && QFileInfo(arcFile).exists()){
     if( KMessageBox::warningContinueCancel(krApp,i18n("The Archive")+PackGUI::filename+"."+PackGUI::type+
-        i18n("\nalready exists, Do you want to overwrite the archive\n")+
+        i18n(" already exists, Do you want to overwrite the archive ")+
         i18n("(all data in previous archive will be lost)"),QString::null,i18n("&Overwrite"))
         == KMessageBox::Cancel) return; // stop operation
 	}
@@ -1208,7 +1222,7 @@ void TreePanelFunc::calcSpace(){
 	QString msg;
   QString fileName = i18n("Name: ")+panel->getCurrentName();
   msg=fileName+i18n("Total occupied space: %1\nin %2 directories and %3 files").
-      arg(KIO::convertSize64(totalSize)).arg(totalDirs).arg(totalFiles);
+  arg(KIO::convertSize(totalSize)).arg(totalDirs).arg(totalFiles);
   KMessageBox::information(krApp,msg.local8Bit());
 }
 
