@@ -171,7 +171,7 @@ void TreePanel::slotRecreateTree(QListViewItem *item) {
   fileList->triggerUpdate();
 }
 
-void TreePanel::refresh(QString){
+void TreePanel::refresh(const QString){
   // change the cursor to busy
 	krApp->setCursor(KCursor::waitCursor());
 	
@@ -211,6 +211,7 @@ void TreePanel::slotFocusOnMe(){		 // give this VFS the focus (the path bar)
   krAddBookmark->setEnabled(false);     // add a bookmark
 	krCompare->setEnabled(false);         // compare by content
   krCompareDirs->setEnabled(false); compareMode=false; otherPanel->compareMode=false;
+	krMultiRename->setEnabled(false);
 }
 
 // this is used to start the panel, AFTER setOther() has been used
@@ -344,7 +345,7 @@ void TreePanel::gotStats(QString data) {
 }
 
 // pops a right-click menu for items
-void TreePanel::popRightClickMenu(QListViewItem* item,QPoint loc) {
+void TreePanel::popRightClickMenu(KListView *kl, QListViewItem* item,const QPoint &loc) {
   // these are the values that will always exist in the menu
   #define OPEN_ID       90
   #define OPEN_WITH_ID  91
