@@ -64,6 +64,7 @@
 #include <kfiledialog.h>
 #include <kdatetbl.h>
 #include <klocale.h>
+#include <kdeversion.h>
 
 // private functions - used as services /////////////////////
 void changeDate(QLineEdit *p) {
@@ -111,13 +112,9 @@ KrSearchDialog::~KrSearchDialog(){
 }
 
 void KrSearchDialog::invalidDateMessage(QLineEdit *p) {
-  #if KDE_VERSION >= 220
 	KMessageBox::detailedError(0, i18n("Invalid date entered."),
                              i18n("The date '") + p->text() + i18n("' is not valid according to your locale.\n"
                              "Please re-enter a valid date (use the date button of easy access)."));
-  #else
-  KMessageBox::error(0, i18n("Invalid date entered."));
-	#endif
 
 	TabWidget2->setCurrentPage(1); // set page to advanced
   p->setFocus();
@@ -344,13 +341,9 @@ bool KrSearchDialog::gui2query() {
   }
   // check that minSize is smaller than maxSize
   if ((query->minSize > 0) && (query->maxSize > 0) && (query->maxSize < query->minSize)) {
-    #if KDE_VERSION >= 220
 		KMessageBox::detailedError(0, i18n("Specified sizes are inconsistent !"),
       i18n("Please re-enter the values, so that the leftmost size will\n"
            "be smaller (or equal) to the right size."));
-    #else
-		KMessageBox::error(0,i18n("Specified sizes are inconsistent !"));
-		#endif
 		TabWidget2->setCurrentPage(1); // set page to advanced
     biggerThanAmount->setFocus();
     return false;
@@ -368,14 +361,10 @@ bool KrSearchDialog::gui2query() {
       if (!d2.isValid()) { invalidDateMessage(modifiedBetweenData2); return false; }
 
       if (d1 > d2) {
-				#if KDE_VERSION >= 220
         KMessageBox::detailedError(0, i18n("Dates are inconsistent !"),
           i18n("The date on the left side is later than the date on the right.\n"
                "Please re-enter the dates, so that the leftmost date will be\n"
                "earlier than the right one."));
-				#else
-				KMessageBox::error(0,i18n("Dates are inconsistent !"));
-				#endif
         TabWidget2->setCurrentPage(1); // set page to advanced
         modifiedBetweenData1->setFocus();
         return false;
@@ -423,14 +412,10 @@ bool KrSearchDialog::gui2query() {
       if ( !modifiedInTheLastData->text().simplifyWhiteSpace().isEmpty() &&
            !notModifiedInTheLastData->text().simplifyWhiteSpace().isEmpty() ) {
         if (d1 > d2) {
-					#if KDE_VERSION >= 220
           KMessageBox::detailedError(0, i18n("Dates are inconsistent !"),
             i18n("The date on the top is later than the date on the bottom.\n"
                  "Please re-enter the dates, so that the top date will be\n"
                  "earlier than the bottom one."));
-					#else
-					KMessageBox::error(0,i18n("Dates are inconsistent !"));
-					#endif
           TabWidget2->setCurrentPage(1); // set page to advanced
           modifiedInTheLastData->setFocus();
           return false;
@@ -457,12 +442,12 @@ bool KrSearchDialog::gui2query() {
 void KrSearchDialog::startSearch() {
   // first, informative messages
   if (searchInArchives->isChecked()) {
-    KMessageBox::information(0, i18n("Since you chose to also search in archives,\n"
+    KMessageBox::information(0, i18n("Since you chose to also search in archives, "
                                      "note the following limitations:\n"
-                                     "1. Krusader will search in all of the supported\n"
-                                     "   archives, NOT INCLUDING arj, and ace.\n"
-                                     "2. You cannot search for text (grep) while doing\n"
-                                     "   a search that includes archives."), 0, "searchInArchives");
+                                     "1. Krusader will search in all of the supported"
+                                       " archives, NOT INCLUDING arj, and ace.\n"
+                                     "2. You cannot search for text (grep) while doing"
+                                       " a search that includes archives."), 0, "searchInArchives");
   }
 
   // prepare the query /////////////////////////////////////////////
