@@ -240,7 +240,7 @@ bool arc_vfs::getDirs(){
     if( !proc.normalExit() || !proc.exitStatus() == 0 ){
      if (!quietMode) KMessageBox::error(krApp,i18n("Can't Read ")+
                     arcFile.mid(arcFile.findRev('/')+1)+
-                    i18n("\nArchive might be corrupted !"));
+                    i18n(" Archive might be corrupted !"));
      error = true;
 		 return false;
     }
@@ -454,7 +454,8 @@ void arc_vfs::vfs_mkdir(QString name){
 	
 // rename file
 void arc_vfs::vfs_rename(QString fileName,QString newName){
-	KURL::List temp(vfs_getFile(fileName));
+	KURL::List temp;
+	temp.append(vfs_getFile(fileName));
   QString path = vfs_origin.right((vfs_origin.length()-vfs_origin.findRev('\\'))-1);
   if(path.left(1)=="/") path.remove(0,1);
   if(path != "") path = path+"/";
@@ -502,7 +503,7 @@ QString arc_vfs::nextWord(QString &s,char d) {
   return temp;
 }
 
-void arc_vfs::getFilesToPack(QStringList* filesToPack,QString dir_name = ""){
+void arc_vfs::getFilesToPack(QStringList* filesToPack,QString dir_name){
   bool newDir = false;
   QList<vfile> *vfs_filesP_backup = vfs_filesP; // save vfs_filesP
 
@@ -547,7 +548,7 @@ void arc_vfs::getFilesToPack(QStringList* filesToPack,QString dir_name = ""){
   vfs_filesP = vfs_filesP_backup; // restore  vfs_filesP
 }
 
-void arc_vfs::getFilesToDelete(QStringList* filesToDelete,QString dir_name = ""){
+void arc_vfs::getFilesToDelete(QStringList* filesToDelete,QString dir_name){
 	// sync the extFiles - and find out which files were deleted
 	QString file;
 	for(unsigned int i=0 ; i<extFiles.count(); ){
@@ -560,7 +561,7 @@ void arc_vfs::getFilesToDelete(QStringList* filesToDelete,QString dir_name = "")
   }
 }
 
-void arc_vfs::getExtFiles( QString dir_name="" ){
+void arc_vfs::getExtFiles(QString dir_name){
 	register DIR* dir = opendir(tmpDir.local8Bit()+"/"+dir_name.local8Bit());
   if(!dir){
     kdWarning() << "faild to opendir(): " << tmpDir.local8Bit()+"/"+dir_name.local8Bit() << endl;
@@ -657,7 +658,7 @@ QList<vfile>* arc_vfs::findDir(QString name){
   return 0;
 }
 
-arc_dir* arc_vfs::findArcDir(QString name){
+arc_vfs::arc_dir* arc_vfs::findArcDir(QString name){
 for(arc_dir* temp = dirList.first();temp != 0 ; temp = dirList.next()){
     if(temp->name == name) return temp;
   }
@@ -797,7 +798,7 @@ void arc_vfs::parseLine(QString line, QFile* temp){
 
     name = qfi.fileName();
     name = name.left(name.findRev('.'));
-    long size = qfi.size();
+    //long size = qfi.size();
     perm  = KRpermHandler::mode2QString(stat_p.st_mode) ;
     dateTime = dateTime2QString(qfi.lastModified());
     owner = KRpermHandler::user2uid(qfi.owner());
