@@ -27,7 +27,8 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-
+// Qt includes
+#include <qdir.h>
 // KDE includes
 #include <kmessagebox.h>
 #include <kprocess.h>
