@@ -48,6 +48,7 @@
 #include <qvaluelist.h>
 // Krusader includes
 #include "krusader.h"
+#include "kicons.h"
 #include "VFS/krpermhandler.h"
 #include "BookMan/bookman.h"
 #include "GUI/krusaderstatus.h"
@@ -62,6 +63,7 @@
 #include "GUI/kfnkeys.h"
 #include "GUI/kcmdline.h"
 #include "krslots.h"
+#include "krservices.h"
 
 // define the static members
 Krusader *Krusader::App=0;
@@ -82,6 +84,7 @@ KAction  *Krusader::actKonfigurator=0;  KAction  *Krusader::actToolsSetup=0;
 KAction  *Krusader::actBack=0;          KAction  *Krusader::actRoot=0;
 KAction  *Krusader::actFind=0;          KAction  *Krusader::actAddBookmark=0;
 KAction  *Krusader::actSavePosition=0;  KAction  *Krusader::actSelectColorMask=0;
+KAction  *Krusader::actMultiRename=0;
 KToggleAction *Krusader::actToggleTerminal=0;
 
 
@@ -99,10 +102,10 @@ Krusader::Krusader() : KParts::MainWindow() {
   QString message;
   switch (config->getConfigState()) {
     case KConfigBase::NoAccess :
-      message="Krusader's configuration file can't be found.\nDefault values will be used.";
+      message="Krusader's configuration file can't be found. Default values will be used.";
       break;
     case KConfigBase::ReadOnly :
-      message="Krusader's configuration file is in READ ONLY mode (why is that !?)\nChanged values will not be saved";
+      message="Krusader's configuration file is in READ ONLY mode (why is that !?) Changed values will not be saved";
       break;
     case KConfigBase::ReadWrite :
       message="";
@@ -112,6 +115,7 @@ Krusader::Krusader() : KParts::MainWindow() {
     KMessageBox::error(krApp,message);
   }
 
+
   // register with the dcop server
 	DCOPClient* client = KApplication::kApplication()->dcopClient();
 	if ( !client->attach() ) exit(0);
@@ -173,7 +177,7 @@ bool Krusader::versionControl() {
   bool retval=false;
   // create config file
   config=kapp->config();
-  QString oldVerText = config->readEntry("Version","100");
+  QString oldVerText = config->readEntry("Version","200");
   oldVerText.truncate(oldVerText.find("-"));
   float oldVer = oldVerText.toFloat();
 	
@@ -181,9 +185,9 @@ bool Krusader::versionControl() {
 
   // older icompatible version
 	if ( oldVer < (9/10) ){
-		KMessageBox::information(krApp,i18n("A configuration older then v0.90,\nwas detected Krusader has to reset your\nconfiguration to default values.\nKrusader will now run Konfigurator."));
+		KMessageBox::information(krApp,i18n("A configuration older then v0.90 was detected Krusader has to reset your configuration to default values. Krusader will now run Konfigurator."));
     if (!QDir::home().remove(".kde/share/config/krusaderrc")) {
-      KMessageBox::error(krApp,i18n("Unable to remove your krusaderrc file !\nPlease remove it manually and rerun Krusader."));
+      KMessageBox::error(krApp,i18n("Unable to remove your krusaderrc file! Please remove it manually and rerun Krusader."));
       exit(1);
     }
     retval=true;
@@ -191,7 +195,7 @@ bool Krusader::versionControl() {
   }
   // first installation of krusader
 	if ( oldVer == 100 ){
-		KMessageBox::information(krApp,i18n("Welcome to Krusader,\nas this is your first run,\nKrusader will now run Konfigurator."));
+		KMessageBox::information(krApp,i18n("Welcome to Krusader, as this is your first run, Krusader will now run Konfigurator."));
   	retval = true;
 	}
 	config->writeEntry("Version",VERSION);
@@ -215,35 +219,35 @@ void Krusader::disableFutureItems() {
 void Krusader::setupAccels() {
   accels = new KAccel(this);
   // F2
-  accels->insertItem("F2 Terminal", "F2_terminal", Key_F2,false);
-  accels->connectItem("F2_terminal",SLOTS, SLOT(terminal()));
+  accels->insert("F2_Terminal", i18n("F2 Terminal"), QString::null,
+                  Key_F2, SLOTS, SLOT(terminal()));
   // F3
-  accels->insertItem("F3 View", "F3_view", Key_F3,false);
-  accels->connectItem("F3_view",SLOTS, SLOT(view()));
+  accels->insert("F3_View", i18n("F3 View"), QString::null,
+                  Key_F3, SLOTS, SLOT(view()));
   // F4
-  accels->insertItem("F4 Edit", "F4_edit", Key_F4,false);
-  accels->connectItem("F4_edit",SLOTS, SLOT(edit()));
+  accels->insert("F4_Edit", i18n("F4 Edit"), QString::null,
+                  Key_F4, SLOTS, SLOT(edit()));
   // F5
-  accels->insertItem("F5-Copy", "F5_copy", Key_F5,false);
-  accels->connectItem("F5_copy",SLOTS, SLOT(copyFiles()));
+  accels->insert("F5_Copy", i18n("F5 Copy"), QString::null,
+                  Key_F5, SLOTS, SLOT(copyFiles()));
   // F6
-  accels->insertItem("F6-Move", "F6_move", Key_F6,false);
-  accels->connectItem("F6_move",SLOTS, SLOT(moveFiles()));
+  accels->insert("F6_Move", i18n("F6 Move"), QString::null,
+                  Key_F6, SLOTS, SLOT(moveFiles()));
   // F7
-  accels->insertItem("F7-Mkdir", "F7_mkdir", Key_F7,false);
-  accels->connectItem("F7_mkdir",SLOTS, SLOT(mkdir()));
+  accels->insert("F7_Mkdir", i18n("F7 Mkdir"), QString::null,
+                  Key_F7, SLOTS, SLOT(mkdir()));
   // F8
-  accels->insertItem("F8-Delete", "F8_delete", Key_F8,false);
-  accels->connectItem("F8_delete",SLOTS, SLOT(deleteFiles()));
+  accels->insert("F8_Delete", i18n("F8 Delete"), QString::null,
+                  Key_F8, SLOTS, SLOT(deleteFiles()));
   // F9
-  accels->insertItem("F9-Rename", "F9_rename", Key_F9,false);
-  accels->connectItem("F9_rename",SLOTS, SLOT(rename()));
+  accels->insert("F9_Rename", i18n("F9 Rename"), QString::null,
+                  Key_F9, SLOTS, SLOT(rename()));
   // F10
-  accels->insertItem("F10-Quit", "F10_quit", Key_F10,false);
-  accels->connectItem("F10_quit",this, SLOT(quitKrusader()));
+  accels->insert("F10_Quit", i18n("F10 Quit"), QString::null,
+                  Key_F10, this, SLOT(quitKrusader()));
   // Tab
-  accels->insertItem("Tab-Switch panel", "tab_switch_panel", Key_Tab,false);
-  accels->connectItem("tab_switch_panel", mainView, SLOT(panelSwitch()));
+  accels->insert("Tab-Switch panel", i18n("Tab: switch panel"), QString::null,
+                  Key_Tab, mainView, SLOT(panelSwitch()));
 
 }
 
@@ -331,7 +335,7 @@ void Krusader::setupActions() {
   actAddBookmark =    new KAction(i18n("Add Bookmark"),     "kr_addbookmark",    CTRL+Key_B,
                         SLOTS,     SLOT(addBookmark()),      actionCollection(), "add bookmark");
   actKonfigurator =   new KAction(i18n("&Konfigurator"),    "configure", 0,
-                        SLOTS,     SLOT(runKonfigurator()),  actionCollection(), "konfigurator");
+                        SLOTS,     SLOT(startKonfigurator()),  actionCollection(), "konfigurator");
 	actBack =           new KAction(i18n("Back"),             "back",         0,
                         SLOTS,     SLOT(back()),             actionCollection(), "back");
   actRoot =           new KAction(i18n("Root"),             "top",  CTRL+Key_Backspace,
@@ -342,15 +346,17 @@ void Krusader::setupActions() {
 	                      krApp,     SLOT(savePosition()),     actionCollection(), "save position");
   actAllFilter =  		new KAction(i18n("&All Files"),  SHIFT+Key_F10,
 												SLOTS, 		SLOT(allFilter()),				 actionCollection(), "all files");
-	actExecFilter = new KAction(i18n("&Executables"),    SHIFT+Key_F11,
-												SLOTS, 		SLOT(execFilter()), 			 actionCollection(), "exec files");
-	actCustomFilter=new KAction(i18n("&Custom"),                                				SHIFT+Key_F12,
-												SLOTS,			SLOT(customFilter()), 		actionCollection(), "custom files");
-  actQuickPanel = new KAction(i18n("&Quickview Panel"), ALT+Key_3,
-												SLOTS,			SLOT(setQuickView()), 		actionCollection(), "quickview panel");
-  actCompare = new KAction(i18n("Compare b&y content"), "kr_compare",
-                           0, SLOTS, SLOT(compareContent()), actionCollection(), "compare");
-  new KAction(i18n("Right-click menu"), Key_Menu,
+	actExecFilter = 		new KAction(i18n("&Executables"),SHIFT+Key_F11,
+												SLOTS, 		SLOT(execFilter()),     	 actionCollection(), "exec files");
+	actCustomFilter=		new KAction(i18n("&Custom"), 				 SHIFT+Key_F12,
+												SLOTS,			SLOT(customFilter()), 	 actionCollection(), "custom files");
+  actQuickPanel = 		new KAction(i18n("&Quickview Panel"), ALT+Key_3,
+												SLOTS,			SLOT(setQuickView()), 	 actionCollection(), "quickview panel");
+  actCompare = 				new KAction(i18n("Compare b&y content"), "kr_compare", 0,
+												SLOTS, SLOT(compareContent()), actionCollection(), "compare");
+  actMultiRename = 		new KAction(i18n("Multi Rename"), "krename", SHIFT+Key_F9,
+                        SLOTS, SLOT(multiRename()), actionCollection(), "multirename");
+	new KAction(i18n("Right-click menu"), Key_Menu,
       				SLOTS,			SLOT(rightclickMenu()), 		actionCollection(), "rightclick menu");
 																
 	// and at last we can set the tool-tips
@@ -536,45 +542,32 @@ void Krusader::updateGUI(bool enforce) {
 // return a list in the format of TOOLS,PATH. for example
 // DIFF,kdiff,TERMINAL,konsole,...
 //
-// currently supported tools: DIFF,
+// currently supported tools: DIFF, MAIL, RENAME
 //
 // to use it: QStringList lst = supportedTools();
 //            int i = lst.findIndex("DIFF");
 //            if (i!=-1) pathToDiff=lst[i+1];
 QStringList Krusader::supportedTools() {
   QStringList tools;
-  bool skip;
-
-  KShellProcess proc;
 
   // first, a diff program: kdiff
-  skip = false;
-  if (!skip) {
-    proc << "which kdiff >/dev/null 2>&1";
-    if( proc.start(KProcess::Block) && proc.normalExit() && proc.exitStatus()==0 ) {
-      tools.append("DIFF"); tools.append("kdiff");
-      skip = true;
-    }
+  if ( KrServices::cmdExist("kdiff") ){
+		tools.append("DIFF"); tools.append("kdiff");
   }
-  if (!skip) {
-    proc.clearArguments();
-    proc << "which xxdiff >/dev/null 2>&1";
-    if( proc.start(KProcess::Block) && proc.normalExit() && proc.exitStatus()==0 ) {
-      tools.append("DIFF"); tools.append("xxdiff");
-      skip = true;
-    }
-  }
-
+	else if ( KrServices::cmdExist("kompare") ) {
+		tools.append("DIFF"); tools.append("kompare");
+	}
+  else if ( KrServices::cmdExist("xxdiff") ) {
+		tools.append("DIFF"); tools.append("xxdiff");
+	}
   // a mailer: kmail
-  skip = false;
-  if (!skip) {
-    proc.clearArguments();
-    proc << "which kmail >/dev/null 2>&1";
-    if( proc.start(KProcess::Block) && proc.normalExit() && proc.exitStatus()==0 ) {
-      tools.append("MAIL"); tools.append("kmail");
-      skip = true;
-    }
-  }
+  if ( KrServices::cmdExist("kmail") ) {
+    tools.append("MAIL"); tools.append("kmail");
+	}
+	// rename tool: krename
+  if ( KrServices::cmdExist("krename") ) {
+  	tools.append("RENAME"); tools.append("krename");
+	}
 
   return tools;
 }
@@ -598,7 +591,7 @@ QString Krusader::getTempDir(){
 	QDir().mkdir(tmpDir);
 
   if( !QDir(tmpDir).isReadable() ){
-    KMessageBox::error(krApp,"Could not create a temporary directory.\nHandling of Archives will not be possible until this is fixed.");
+    KMessageBox::error(krApp,"Could not create a temporary directory. Handling of Archives will not be possible until this is fixed.");
 		return QString::null;
 	}
 	return tmpDir;
