@@ -94,7 +94,12 @@ KrusaderView::KrusaderView(QWidget *parent, const char *name ) : QWidget(parent,
 
 // updates the command line whenever current panel changes
 //////////////////////////////////////////////////////////
-void KrusaderView::slotCurrentChanged(QString p) { cmdLine->setCurrent(p); }
+void KrusaderView::slotCurrentChanged(QString p) {
+  cmdLine->setCurrent(p);
+  if (konsole_part != 0L) {
+    konsole_part->openURL(KURL(p));
+  }
+}
 
 void KrusaderView::setQuickView() {
   KVFSPanel *temp;
